==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_file.js <==
_me = frm_file.prototype;
function frm_file(){};

_me.__constructor = function() {
	this._defaultSize();

    if (this._aValues.fullpath)
		this._draw('frm_file', 'main',{folders:true});
	else
		this._draw('frm_file', 'main');
		
	this.__initForm('FILE::FILE');

	if (this.x_folders){
		var me = this;
		this.x_folders._onclick = function(){
			gui._create('frm_select_folder','frm_select_folder','','','POPUP_FOLDERS::SELECT_FOLDER',me._sAccountID,me._sFolderID,[me,'__changeFolder'],true,true,'F','',false);
		};
	}
};

_me.__loadItems = function() {

	loadDataIntoForm(this, this._aValues);

	if (this._aValues['ATTACHMENTS']){
		if (this._aValues.fullpath){
			this.X_ATTACHMENTS._value({'path':this._aValues.fullpath,'values': this._aValues['ATTACHMENTS']});
			this.X_ATTACHMENTS.__bPassed = true;
		}
		else
			this.X_ATTACHMENTS._value({'path': this._sAccountID+'/'+this._sFolderID+'/'+this._sItemID, 'values': this._aValues['ATTACHMENTS']});
	}
	else
	if (this._aValues['PUSH_ATTACHMENTS'])
		this.X_ATTACHMENTS.__addItem(this._aValues['PUSH_ATTACHMENTS'][0]);
};

_me.__changeFolder = function(sAccount,sFolder){
	this._sAccountID = sAccount;
	this._sFolderID = sFolder;
	this._id = [sAccount, sFolder];
};

_me.__saveItems = function(aValues) {
	
	var addon;
	if (!Is.Empty(addon = this.X_ATTACHMENTS._value())) {
		var now = new Date();

		aValues['values']['EVNTITLE'] = addon[0]['values']['description'];
		aValues['values']['EVNLOCATION'] = this.X_ATTACHMENTS._getName();
		aValues['values']['EVNCOMPLETE'] = this.X_ATTACHMENTS._getSize();
		aValues['values']['EVNSTARTDATE'] = now.getJulianDate();
		aValues['values']['EVNSTARTTIME'] = now.getHours()*60 + now.getMinutes();
	
		aValues['ATTACHMENTS'] = addon;
	}
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_file.js <==
_me = frm_file.prototype;
function frm_file(){};

_me.__constructor = function() {
	this._defaultSize();

    if (this._aValues.fullpath)
		this._draw('frm_file', 'main',{folders:true});
	else
		this._draw('frm_file', 'main');
		
	this.__initForm('FILE::FILE');

	if (this.x_folders){
		var me = this;
		this.x_folders._onclick = function(){
			gui._create('frm_select_folder','frm_select_folder','','','POPUP_FOLDERS::SELECT_FOLDER',me._sAccountID,me._sFolderID,[me,'__changeFolder'],true,true,'F','',false);
		};
	}
	
	this.X_ATTACHMENTS._onuploadstart = function(){
		this._parent.x_btn_ok._disabled(true);
		//this._parent.x_btn_cancel._disabled(true);
	};
	this.X_ATTACHMENTS._onuploadend = function(){
		this._parent.x_btn_ok._disabled(false);
		//this._parent.x_btn_cancel._disabled(false);
	};
};

_me.__loadItems = function() {

	loadDataIntoForm(this, this._aValues);

	if (this._aValues['ATTACHMENTS']){
		if (this._aValues.fullpath){
			this.X_ATTACHMENTS._value({'path':this._aValues.fullpath,'values': this._aValues['ATTACHMENTS']});
			this.X_ATTACHMENTS.__bPassed = true;
		}
		else
			this.X_ATTACHMENTS._value({'path': this._sAccountID+'/'+this._sFolderID+'/'+this._sItemID, 'values': this._aValues['ATTACHMENTS']});
	}
	else
	if (this._aValues['PUSH_ATTACHMENTS'])
		this.X_ATTACHMENTS.__addItem(this._aValues['PUSH_ATTACHMENTS'][0]);
};

_me.__changeFolder = function(sAccount,sFolder){
	this._sAccountID = sAccount;
	this._sFolderID = sFolder;
	this._id = [sAccount, sFolder];
};

_me.__saveItems = function(aValues) {
	
	var addon;
	if (!Is.Empty(addon = this.X_ATTACHMENTS._value())) {
		var now = new Date();

		aValues['values']['EVNTITLE'] = addon[addon.length-1]['values']['description'];
		aValues['values']['EVNLOCATION'] = this.X_ATTACHMENTS._getName();
		aValues['values']['EVNCOMPLETE'] = this.X_ATTACHMENTS._getSize();
		aValues['values']['EVNSTARTDATE'] = now.getJulianDate();
		aValues['values']['EVNSTARTTIME'] = now.getHours()*60 + now.getMinutes();
	
		aValues['ATTACHMENTS'] = addon;
	}
};
